#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_INTERLEAVE_SECOND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_INTERLEAVE_SECOND_HPP_INCLUDED

#include <nt2/swar/include/functions/scalar/interleave_second.hpp>

#endif
